 local agent_helper = require(AGENT_PATH .. "agent_helper")

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)
end

AgentAdapter = {
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.cp01.youyannet.com/hx1/login_verify.php",

	uid = "",
}

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.is_init = true
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "hx1"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "hx1_" .. self.uid
end


--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[26]--寻仙记
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_xxj"
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "loading_bg_empty"
end


function AgentAdapter:LoginCallback(result)
	print("AgentAdapter:LoginCallback:" .. result)
	local json_obj = cjson.decode(result)

	if nil == json_obj or nil == json_obj.uid or nil == json_obj.sid then return end
	self.uid = json_obj.uid
	self.username = json_obj.username
	self.nickname = json_obj.nickname
	self.sid = json_obj.sid
	self.login_callback(self:GetPlatName(), json_obj.sid)
	return false
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:LogoutCallback(result)
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end
	local json_obj = {}
	json_obj.role_id = role_id
	json_obj.servername = server_id
	json_obj.playername = RoleData.Instance.role_vo.name or ""
	json_obj.amount = amount .. ".00"
	json_obj.productname = "元宝" --商品名称
	json_obj.body = "元宝" --商品描述
	json_obj.order = server_id .. "_" .. self.uid .. "_" .. os.time()
	Log(cjson.encode(json_obj))
	agent_helper:Pay(cjson.encode(json_obj), nil)
end



--元宝变化
function AgentAdapter:OnMoneyChange(gold)
	Log("OnMoneyChange==================")
	Log(gold)
	PlatformBinder:JsonCall("call_agent_on_money_change", gold)
end

function AgentAdapter:SubmitRoleInfoAck()
	self:SubmitInfo(1)
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self:SubmitInfo(0)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end

function AgentAdapter:SubmitInfo(type)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	if role_vo ~= nil and user_vo ~= nil then
		local info = {}
		info.type = type
		info.uid = self.uid
		info.server_id = tostring(user_vo.plat_server_id)
		info.server_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		info.role_name = role_vo.name
		info.role_id = tostring(role_vo.role_id)
		info.user_level = tostring(role_vo.level) or "0"
		info.vip_level = tostring(role_vo.vip_level) or "0"

		info.camp_name = Language.Common.CampName2[role_vo.camp or "0"]	--阵营名字
		info.prof_name =  Language.Common.ProfName[role_vo.prof or "0"]	--职业名字

		if RoleData.Instance and RoleData.Instance.role_info then
			info.gold = RoleData.Instance.role_info.gold or "0"
			info.party_name = RoleData.Instance.role_vo.guild_name or ""
		else
			info.gold = "0"
			info.party_name = ""
		end
		info.sub_type = type

		print(cjson.encode(info))
		PlatformBinder:JsonCall("send_user_info", cjson.encode(info))
	end
end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end
